==> e_commerce-0.2.4-sources.jar: ai/causalfoundry/android/sdk/e_commerce/builders/CfLogItemRequestEvent.kt <==
package ai.causalfoundry.android.sdk.e_commerce.builders

import ai.causalfoundry.android.sdk.core.CFSetup
import ai.causalfoundry.android.sdk.core.utils.CoreConstants
import ai.causalfoundry.android.sdk.core.utils.ExceptionManager
import ai.causalfoundry.android.sdk.e_commerce.event_models.event_objects.ItemRequestObject
import ai.causalfoundry.android.sdk.e_commerce.event_types.EComEventType
import ai.causalfoundry.android.sdk.e_commerce.utils.ECommerceConstants

/**
 * Created by Moiz Hassan on 04 April, 2023
 */

class CfLogItemRequestEvent {

    /**
     * CfLogItemRequestEvent is used to log the event an item is requested.
     */

    data class Builder(
        internal var item_request_id: String? = null,
        internal var item_name: String? = null,
        internal var manufacturer: String? = null,
        private var meta: Any? = null,
        private var update_immediately: Boolean = CoreConstants.updateImmediately
    ) {

        /**
         * setItemRequestId is for the providing Item name requested by the user.
         */
        fun setItemRequestId(item_request_id: String) = apply {
            this.item_request_id = item_request_id
        }

        /**
         * setItemName is for the providing Item name requested by the user.
         */
        fun setItemName(item_name: String) = apply {
            this.item_name = item_name
        }

        /**
         * setItemManufacturer is for the providing manufacturer for the item requested by the user.
         */
        fun setItemManufacturer(manufacturer: String) = apply {
            this.manufacturer = manufacturer
        }

        /**
         * You can pass any type of value in setMeta. It is for developer and partners to log
         * additional information with the log that they find would be helpful for logging and
         * providing more context to the log. Default value for the meta is null.
         */
        fun setMeta(meta: Any?) = apply { this.meta = meta }

        /**
         * updateImmediately is responsible for updating the values ot the backend immediately.
         * By default this is set to false or whatever the developer has set in the SDK
         * initialisation block. This differs the time for which the logs will be logged, if true,
         * the SDK will log the content instantly and if false it will wait till the end of user
         * session which is whenever the app goes into background.
         */
        fun updateImmediately(update_immediately: Boolean) =
            apply { this.update_immediately = update_immediately }

        /**
         * build will validate all of the values provided and if passes will call the track
         * function and queue the events based on it's updateImmediately value and also on the
         * user's network resources.
         */
        fun build() = apply {
            when {

                /**
                 * Will throw an exception for the developer if id provided is null or not
                 * provided at all.
                 */
                item_request_id.isNullOrEmpty() -> {
                    ExceptionManager.throwIsRequiredException(
                        EComEventType.item_request.name,
                        "item_request_id"
                    )
                }

                /**
                 * Will throw an exception for the developer if name provided is null or not
                 * provided at all.
                 */
                item_name.isNullOrEmpty() -> {
                    ExceptionManager.throwIsRequiredException(
                        EComEventType.item_request.name,
                        "item_name"
                    )
                }

                /**
                 * Will throw an exception for the developer if manufacturer provided is null or not
                 * provided at all.
                 */
                manufacturer.isNullOrEmpty() -> {
                    ExceptionManager.throwIsRequiredException(
                        EComEventType.item_request.name,
                        "manufacturer"
                    )
                }

                else -> {
                    /**
                     * Parsing the values into an object and passing to the setup block to queue
                     * the event based on its priority.
                     */
                    val itemRequestObject = ItemRequestObject(
                        item_request_id!!, item_name!!, manufacturer!!, meta
                    )
                    CFSetup().track(
                        ECommerceConstants.contentBlockName, EComEventType.item_request.name,
                        itemRequestObject, update_immediately
                    )
                }
            }
        }

    }
}

==> e_commerce-0.6.4-sources.jar: ai/causalfoundry/android/sdk/e_commerce/builders/CfLogItemRequestEvent.kt <==
package ai.causalfoundry.android.sdk.e_commerce.builders

import ai.causalfoundry.android.sdk.core.CFSetup
import ai.causalfoundry.android.sdk.core.utils.CoreConstants
import ai.causalfoundry.android.sdk.core.utils.ExceptionManager
import ai.causalfoundry.android.sdk.e_commerce.event_models.event_objects.ItemRequestObject
import ai.causalfoundry.android.sdk.e_commerce.event_types.EComEventType
import ai.causalfoundry.android.sdk.e_commerce.utils.ECommerceConstants

/**
 * Created by Moiz Hassan on 04 April, 2023
 */

class CfLogItemRequestEvent {

    /**
     * CfLogItemRequestEvent is used to log the event an item is requested.
     */

    data class Builder(
        internal var itemRequestIdValue: String? = null,
        internal var itemNameValue: String? = null,
        internal var manufacturerValue: String? = null,
        private var meta: Any? = null,
        private var isUpdateImmediately: Boolean = CoreConstants.updateImmediately
    ) {

        /**
         * setItemRequestId is for the providing Item name requested by the user.
         */
        fun setItemRequestId(itemRequestId: String) = apply {
            this.itemRequestIdValue = itemRequestId
        }

        /**
         * setItemName is for the providing Item name requested by the user.
         */
        fun setItemName(itemName: String) = apply {
            this.itemNameValue = itemName
        }

        /**
         * setItemManufacturer is for the providing manufacturer for the item requested by the user.
         */
        fun setItemManufacturer(manufacturer: String) = apply {
            this.manufacturerValue = manufacturer
        }

        /**
         * You can pass any type of value in setMeta. It is for developer and partners to log
         * additional information with the log that they find would be helpful for logging and
         * providing more context to the log. Default value for the meta is null.
         */
        fun setMeta(meta: Any?) = apply { this.meta = meta }

        /**
         * updateImmediately is responsible for updating the values ot the backend immediately.
         * By default this is set to false or whatever the developer has set in the SDK
         * initialisation block. This differs the time for which the logs will be logged, if true,
         * the SDK will log the content instantly and if false it will wait till the end of user
         * session which is whenever the app goes into background.
         */
        fun updateImmediately(updateImmediately: Boolean) =
            apply { this.isUpdateImmediately = updateImmediately }

        /**
         * build will validate all of the values provided and if passes will call the track
         * function and queue the events based on it's updateImmediately value and also on the
         * user's network resources.
         */
        fun build() = apply {
            when {

                /**
                 * Will throw an exception for the developer if id provided is null or not
                 * provided at all.
                 */
                itemRequestIdValue.isNullOrEmpty() -> {
                    ExceptionManager.throwIsRequiredException(
                        EComEventType.item_request.name,
                        "item_request_id"
                    )
                }

                /**
                 * Will throw an exception for the developer if name provided is null or not
                 * provided at all.
                 */
                itemNameValue.isNullOrEmpty() -> {
                    ExceptionManager.throwIsRequiredException(
                        EComEventType.item_request.name,
                        "item_name"
                    )
                }

                /**
                 * Will throw an exception for the developer if manufacturer provided is null or not
                 * provided at all.
                 */
                manufacturerValue.isNullOrEmpty() -> {
                    ExceptionManager.throwIsRequiredException(
                        EComEventType.item_request.name,
                        "manufacturer"
                    )
                }

                else -> {
                    /**
                     * Parsing the values into an object and passing to the setup block to queue
                     * the event based on its priority.
                     */
                    val itemRequestObject = ItemRequestObject(
                        itemRequestIdValue!!, itemNameValue!!, manufacturerValue!!, meta
                    )
                    CFSetup().track(
                        ECommerceConstants.contentBlockName, EComEventType.item_request.name,
                        itemRequestObject, isUpdateImmediately
                    )
                }
            }
        }

    }
}
